
<table>
	<tr>
		<th>Nafn</th>
		<th>Kennitala</th>
		<th>Age</th>
		<th>Address</th>
		<th>Postcode</th>
	</tr>
	{%for person in object_list%}
		<tr>
			<td>{{person.name}}</td>
			<td>{{person.ssn}}</td>
			<td>{{person.age}}</td>
			<td>{{person.address}}</td>
			<td>{{person.postcode}}</td>
		</tr>
	{%endfor%}
</table>
{% if is_paginated %}
	<div class="pagination">
		<span class="page-links">
			{% if page_obj.has_previous %}
				<a href="{%url 'thjodskra_list'%}?{{search_query}}&page={{ page_obj.previous_page_number }}">previous</a>
			{% endif %}
			<span class="page-current">
				Page {{ page_obj.number }} of {{ page_obj.paginator.num_pages }}.
			</span>
			{% if page_obj.has_next %}
				<a href="{%url 'thjodskra_list'%}?{{search_query}}&page={{ page_obj.next_page_number }}">next</a>
			{% endif %}
		</span>
	</div>
{% endif %}